@@ -1,65 +1,70 @@
-from typing import IO, List, Type
+from typing import List, Type, Union
 from os.path import join
 
 from cfinterface.components.section import Section
 from cfinterface.components.defaultsection import DefaultSection
 from cfinterface.data.sectiondata import SectionData
 
+from cfinterface.adapters.reading.repository import Repository, factory
+
 
 class SectionReading:
     """
     Class for reading custom files based on a SectionData structure.
     """
 
-    def __init__(self, sections: List[Type[Section]]) -> None:
+    def __init__(
+        self,
+        sections: List[Type[Section]],
+        storage: str = "",
+        linesize: int = 1,
+    ) -> None:
         self.__sections = sections
         self.__data = SectionData(DefaultSection(data=""))
         self.__last_position_filepointer = 0
+        self.__storage = storage
+        self.__repository: Repository = None  # type: ignore
+        self.__linesize = linesize
 
-    def __read_line_with_backup(self, file: IO) -> str:
+    def __read_line_with_backup(self) -> Union[str, bytes]:
         """
         Reads a line of the file, saving the filepointer position
         in case one desired to return to the previous line.
 
-        :param file: THe filepoiner for the reading file
-        :type file: IO
-        :return: The read line
-        :rtype: str
-        """
-        self.__last_position_filepointer = file.tell()
-        return file.readline()
 
-    def __restore_previous_line(self, file: IO):
+        :return: The read line
+        :rtype: str | bytes
+        """
+        self.__last_position_filepointer = self.__repository.file.tell()
+        return self.__repository.read(self.__linesize)
+
+    def __restore_previous_line(self):
         """
         Restores the filepointer to the beginning of the previously
         read line.
 
-        :param file: The filepointer
-        :type file: IO
         """
-        file.seek(self.__last_position_filepointer)
+        self.__repository.file.seek(self.__last_position_filepointer)
 
-    def __read_file(self, file: IO) -> SectionData:
+    def __read_file(self) -> SectionData:
         """
         Reads all the sections from a file and
         returns the SectionData structure.
 
-        :param file: The filepointer
-        :type file: IO
         :return: The section data from the file
         :rtype: SectionData
         """
         for sectiontype in self.__sections:
             section = sectiontype()
-            section.read(file)
+            section.read(self.__repository.file)
             self.__data.append(section)
         while True:
-            line = self.__read_line_with_backup(file)
+            line = self.__read_line_with_backup()
             if len(line) == 0:
                 break
-            self.__restore_previous_line(file)
+            self.__restore_previous_line()
             section = DefaultSection()
-            section.read(file)
+            section.read(self.__repository.file)
             self.__data.append(section)
         return self.__data
 
@@ -80,8 +85,9 @@ class SectionReading:
         :rtype: SectionData
         """
         filepath = join(directory, filename)
-        with open(filepath, "r", encoding=encoding) as fp:
-            return self.__read_file(fp)
+        self.__repository = factory(self.__storage)(filepath, encoding)
+        with self.__repository:
+            return self.__read_file()
 
     @property
     def data(self) -> SectionData:
